@@ -68,7 +68,7 @@ def cli():
     """IFermi is a tool for the generation, analysis and plotting of Fermi surfaces."""
 
     def _warning(message, *_, **__):
-        click.echo("WARNING: {}\n".format(message))
+        click.echo(f"WARNING: {message}\n")
 
     warnings.showwarning = _warning
 
@@ -236,6 +236,12 @@ def info(filename, **kwargs):
 @option(
     "--hide-surface", is_flag=True, help="hide the Fermi surface", show_default=True
 )
+@option(
+    "--plot-index",
+    multiple=True,
+    default=None,
+    help="plot specific bands indices (1 based)",
+)
 @option(
     "--hide-labels",
     is_flag=True,
@@ -289,6 +295,14 @@ def plot(filename, **kwargs):
     spin = {"up": Spin.up, "down": Spin.down, None: None}[kwargs["spin"]]
     projection_axis = kwargs["projection_axis"] or None
 
+    if len(kwargs["plot_index"]) > 0:
+        # user specified bands start at 1 but python api expects 0-based indices
+        kwargs["plot_index"] = [int(i) - 1 for i in kwargs["plot_index"]]
+    else:
+        # click automatically converts plot_index to list, even though the default
+        # should be None
+        kwargs["plot_index"] = None
+
     if kwargs["slice"]:
         plane_normal = kwargs["slice"][:3]
         distance = kwargs["slice"][3]
@@ -308,6 +322,7 @@ def plot(filename, **kwargs):
             hide_labels=kwargs["hide_labels"],
             hide_cell=kwargs["hide_cell"],
             scale_linewidth=kwargs["scale_linewidth"],
+            plot_index=kwargs["plot_index"],
         )
     else:
         plotter = FermiSurfacePlotter(fs, symprec=kwargs["symprec"])
@@ -326,12 +341,13 @@ def plot(filename, **kwargs):
             hide_surface=kwargs["hide_surface"],
             hide_labels=kwargs["hide_labels"],
             hide_cell=kwargs["hide_cell"],
+            plot_index=kwargs["plot_index"],
         )
 
     if output_filename is None:
         show_plot(fig)
     else:
-        click.echo("Saving plot to {}".format(output_filename))
+        click.echo(f"Saving plot to {output_filename}")
         save_plot(fig, output_filename, scale=kwargs["scale"])
 
 
